@@ -14,9 +14,4 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.discovery.dfg import algorithm, replacement, variants, utils
-import pkgutil
-
-if pkgutil.find_loader("pandas"):
-    from pm4py.algo.discovery.dfg import adapters
-
+from pm4py.algo.discovery.dfg import adapters, variants, algorithm, replacement, utils
