@@ -22,6 +22,8 @@ from pm4py.objects.log.obj import EventLog
 from pm4py.util import xes_constants
 from pm4py.util import exec_utils
 from enum import Enum
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog, EventStream
 
 
 class Outputs(Enum):
@@ -41,7 +43,7 @@ class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
 
 
-def apply(log, parameters=None):
+def apply(log, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Dict[str, Any]:
     """
     Discovers a footprint object from an event log
     (the footprints are returned case-by-case)
