@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.bpmn.bpmn_graph import BPMN
+from pm4py.objects.bpmn.obj import BPMN
 
 
 def reduce_xor_gateways(bpmn_graph, parameters=None):
