@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.statistics.util import times_bipartite_matching
+
+import warnings
+
+warnings.warn("The statistics.util package will be removed in a future release.")
